@@ -7,8 +7,7 @@ fn test_cursor_pos() {
     let pos = AnsiSequence::CursorPos(5, 20);
     let mut buff = String::new();
 
-    write!(&mut buff, "{}", pos)
-        .expect("failed to write");
+    write!(&mut buff, "{}", pos).expect("failed to write");
 
     assert_eq!(buff, "\x1b[5;20H");
 }
